@@ -89,10 +89,6 @@ and from_path g root path =
   let t = get_inspection g root in
   { t with virtio_win = path; was_set = true }
 
-and from_libosinfo g root =
-  let t = get_inspection g root in
-  { t with virtio_win = ""; was_set = false }
-
 and get_inspection g root =
   (* Fail hard if inspection hasn't been done or it's not a Windows
    * guest.  If it happens it indicates an internal error in the
@@ -132,45 +128,25 @@ let rec inject_virtio_win_drivers ({ g } as t) reg =
   (* XXX Inelegant hack copied originally from [Convert_windows].
    * We should be able to work this into the code properly later.
    *)
-  let (machine : machine_type), virtio_1_0 =
+  let (machine : machine_type) =
     match t.i_arch with
     | ("i386"|"x86_64") ->
-       (try
-          (* Fall back to the decision that's based on the year that the OS
-           * was released in under three circumstances:
-           * - the user specified the location of the Windows virtio drivers
-           *   through an environment variable, or
-           * - "Libosinfo_utils.get_os_by_short_id" fails to look up the OS,
-           *   or
-           * - "Libosinfo_utils.best_driver" cannot find any matching driver.
-           * In each of these cases, a "Not_found" exception is raised.  This
-           * behavior exactly mirrors that of "Windows_virtio.copy_drivers".
-           *)
-          if t.was_set then raise Not_found;
-          let os = Libosinfo_utils.get_os_by_short_id t.i_osinfo in
-          let devices = os#get_devices ()
-          and drivers = os#get_device_drivers () in
-          let best_drv_devs =
-            (Libosinfo_utils.best_driver drivers t.i_arch).devices in
-          debug "libosinfo internal devices for OS \"%s\":\n%s"
-            t.i_osinfo
-            (Libosinfo_utils.string_of_osinfo_device_list devices);
-          debug "libosinfo \"best driver\" devices for OS \"%s\":\n%s"
-            t.i_osinfo
-            (Libosinfo_utils.string_of_osinfo_device_list best_drv_devs);
-          let { Libosinfo_utils.q35; vio10 } =
-            Libosinfo_utils.os_support_of_osinfo_device_list
-              (devices @ best_drv_devs) in
-          (if q35 then Q35 else I440FX), vio10
-        with
-        | Not_found ->
+       (match Libosinfo_utils.get_os_by_short_id t.i_osinfo with
+        | Some os ->
+           let devices = os#get_devices () in
+           debug "libosinfo devices for OS \"%s\":\n%s" t.i_osinfo
+             (Libosinfo_utils.string_of_osinfo_device_list devices);
+           (if Libosinfo_utils.os_devices_supports_q35 devices then Q35
+            else I440FX)
+        | None ->
            (* Pivot on the year 2007.  Any Windows version from earlier than
             * 2007 should use i440fx, anything 2007 or newer should use q35.
             * Luckily this coincides almost exactly with the release of NT 6.
             *)
-           (if t.i_major_version < 6 then I440FX else Q35), true
+           debug "osinfo lookup failed. falling back to heuristic for windows machine type";
+           (if t.i_major_version < 6 then I440FX else Q35)
        )
-    | _ -> Virt, true
+    | _ -> Virt
   in
 
   if not (copy_drivers t driverdir) then (
@@ -180,7 +156,7 @@ let rec inject_virtio_win_drivers ({ g } as t) reg =
       { block_driver = IDE; net_driver = RTL8139;
         virtio_rng = false; virtio_balloon = false;
         isa_pvpanic = false; virtio_socket = false;
-        machine; virtio_1_0; }
+        machine; virtio_1_0 = true; }
   )
   else (
     (* Can we install the block driver? *)
@@ -259,7 +235,7 @@ let rec inject_virtio_win_drivers ({ g } as t) reg =
       virtio_balloon = g#exists (driverdir // "balloon.inf");
       isa_pvpanic = g#exists (driverdir // "pvpanic.inf");
       virtio_socket = g#exists (driverdir // "viosock.inf");
-      machine; virtio_1_0;
+      machine; virtio_1_0 = true;
     }
   )
 
@@ -334,8 +310,13 @@ and ddb_regedits inspect drv_name drv_pciid =
    * one must add keys into the DriverDatabase.
    *)
 
+  let winarch =
+    match inspect.i_arch with
+    | "i386" -> "x86" | "x86_64" -> "amd64"
+    | _ -> assert false in
+
   let drv_inf = "guestor.inf" in
-  let drv_inf_label = drv_inf ^ "_tmp" in
+  let drv_inf_label = sprintf "%s_%s_0000000000000000" drv_inf winarch in
   let drv_config = "guestor_conf" in
 
   [
@@ -368,7 +349,6 @@ and ddb_regedits inspect drv_name drv_pciid =
  * been copied.
  *)
 and copy_drivers t driverdir =
-  (not t.was_set && [] <> copy_from_libosinfo t driverdir) ||
     [] <> copy_from_virtio_win t "/" driverdir
             (virtio_iso_path_matches_guest_os t)
       (fun () ->
@@ -463,8 +443,7 @@ and copy_from_virtio_win ({ g } as t) srcdir destdir filter missing =
  * specific Windows flavor of the current guest.
  *)
 and virtio_iso_path_matches_guest_os t path =
-  let { i_major_version = os_major; i_minor_version = os_minor;
-        i_arch = arch; i_product_variant = os_variant;
+  let { i_arch = arch;
         i_osinfo = osinfo } = t in
   try
     (* Lowercased path, since the ISO may contain upper or lowercase path
@@ -480,59 +459,65 @@ and virtio_iso_path_matches_guest_os t path =
      *)
     let pathelem elem =
       String.find lc_path ("/" ^ elem ^ "/") >= 0 ||
-      String.is_prefix lc_path (elem ^ "/")
+      String.starts_with (elem ^ "/") lc_path
     in
     let p_arch =
       if pathelem "x86" || pathelem "i386" then "i386"
       else if pathelem "amd64" then "x86_64"
       else raise Not_found in
 
-    let is_client os_variant = os_variant = "Client"
-    and not_client os_variant = os_variant <> "Client"
-    and any_variant os_variant = true
-    and any_osinfo osinfo = true in
-    let p_os_major, p_os_minor, match_os_variant, match_osinfo =
+    let match_osinfo =
       if pathelem "xp" then
-        (5, 1, any_variant, any_osinfo)
+        ((=) "winxp")
       else if pathelem "2k3" then
-        (5, 2, any_variant, any_osinfo)
+        (function "win2k3" | "win2k3r2" -> true | _ -> false)
       else if pathelem "vista" then
-        (6, 0, is_client, any_osinfo)
+        ((=) "winvista")
       else if pathelem "2k8" then
-        (6, 0, not_client, any_osinfo)
+        ((=) "win2k8")
       else if pathelem "w7" then
-        (6, 1, is_client, any_osinfo)
+        ((=) "win7")
       else if pathelem "2k8r2" then
-        (6, 1, not_client, any_osinfo)
+        ((=) "win2k8r2")
       else if pathelem "w8" then
-        (6, 2, is_client, any_osinfo)
+        ((=) "win8")
       else if pathelem "2k12" then
-        (6, 2, not_client, any_osinfo)
+        ((=) "win2k12")
       else if pathelem "w8.1" then
-        (6, 3, is_client, any_osinfo)
+        ((=) "win8.1")
       else if pathelem "2k12r2" then
-        (6, 3, not_client, any_osinfo)
+        ((=) "win2k12r2")
       else if pathelem "w10" then
-        (10, 0, is_client, ((=) "win10"))
+        ((=) "win10")
       else if pathelem "w11" then
-        (10, 0, is_client, ((=) "win11"))
+        ((=) "win11")
       else if pathelem "2k16" then
-        (10, 0, not_client, ((=) "win2k16"))
+        ((=) "win2k16")
       else if pathelem "2k19" then
-        (10, 0, not_client, ((=) "win2k19"))
+        ((=) "win2k19")
       else if pathelem "2k22" then
-        (10, 0, not_client, ((=) "win2k22"))
+        ((=) "win2k22")
       else if pathelem "2k25" then
-        (10, 0, not_client, ((=) "win2k25"))
+        ((=) "win2k25")
       else
         raise Not_found in
 
-    let p_sriov = pathelem "sriov" in
+    (* https://issues.redhat.com/browse/RHEL-56383
+     * sriov/ dir can have files that conflict with netkvm driver install.
+     *)
+    let p_sriov =
+      String.find path "vioprot." >= 0 ||
+      pathelem "sriov"
+    in
+
+    (* .pdb files are debugging files. they are not part of the
+     * signed driver and are not necessary to install.
+     *)
+    let p_pdb = String.ends_with ".pdb" path in
 
     arch = p_arch &&
-    not p_sriov && (* always ignored, see RHEL-56383 *)
-    os_major = p_os_major && os_minor = p_os_minor &&
-    match_os_variant os_variant &&
+    not p_sriov &&
+    not p_pdb &&
     match_osinfo osinfo
 
   with Not_found -> false
@@ -559,45 +544,6 @@ and virtio_iso_path_matches_qemu_ga t path =
 and virtio_iso_path_matches_blnsvr t path =
   virtio_iso_path_matches_guest_os t path && PCRE.matches re_blnsvr path
 
-(* Look up in libosinfo for the OS, and copy all the locally
- * available files specified as drivers for that OS to the [destdir].
- *
- * This function does nothing in case either:
- * - the osinfo short ID is not found in the libosinfo DB
- * - the OS does not have any driver for the architecture of the guest
- * - the location of the drivers is not a local directory
- *
- * Files that do not exist are silently skipped.
- *
- * Returns list of copied files.
- *)
-and copy_from_libosinfo { g; i_osinfo; i_arch } destdir =
-  try
-    let os = Libosinfo_utils.get_os_by_short_id i_osinfo in
-    let drivers = os#get_device_drivers () in
-    let driver = Libosinfo_utils.best_driver drivers i_arch in
-    let uri = Xml.parse_uri driver.Libosinfo.location in
-    let basedir =
-      match uri.Xml.uri_path with
-      | Some p -> p
-      | None -> assert false in
-    List.filter_map (
-      fun f ->
-        let source = basedir // f in
-        if not (Sys.file_exists source) then
-          None
-        else (
-          let target_name = String.lowercase_ascii (Filename.basename f) in
-          let target = destdir ^ "/" ^ target_name in
-          debug "windows: copying guest tools bits (via libosinfo): 'host:%s' -> '%s'"
-                source target;
-
-          g#write target (read_whole_file source);
-          Some target_name
-        )
-    ) driver.Libosinfo.files
-  with Not_found -> []
-
 (* Install qemu-ga.  [files] is the non-empty list of possible qemu-ga
  * installers we detected.
  *)
